(function(window) {
	app = {};
	//app初始化
	app.init = function(name) {
		$api.fixStatusBar($api.dom('.header'));
		//android监听返回健
		app.listen('keyback', function() {
			api.closeWidget();
		});
		//监听页面加载
		app.listen(name + '-loading', function() {
			api.showProgress({
				style : 'default',
				animationType : 'fade',
				title : '努力加载中...',
				text : '正在加载中...',
				modal : false
			});
		})
		app.sendEvent(name + '-loading');
	}
	app.isNetworkConnect = function() {
		var type = api.connectionType;

		if ('none' == type) {
			app.toast('网络连接失败');
			return false;
		}
		return true;
	}
	app.toast = function(msg) {
		api.toast({
			msg : msg,
			duration : 2000,
			location : 'middle'
		});
	}
	/**
	 * 对数据进行json字符串转化
	 */
	app.json = function(data) {
		return JSON.stringify(data);
		//将JSON对象转化为JSON字符
	}
	app.cache = function(key, value) {

	}

	app.imageCache = function(url, callback) {
		api.imageCache({
			url : url
		}, function(res, err) {
			if (res) {
				if ( typeof callback == 'function')
					callback(res);
			} else {
				app.toast("文件缓存失败");
			}
		});
	}
	/**
	 *将数据写入到文件中
	 * @param {Object} name 文件名
	 * @param {Object} data 数据
	 * @param {Object} append 是否追加 默认不追加
	 * @param {Object} callback 回调函数 用于数据写入成功后进行的操作
	 */
	app.write = function(name, data, append, callback) {
		var flag = append || false;
		var param = {
			path : 'fs://' + name,
			data : data,
			append : flag
		};
		api.writeFile(param, function(res, err) {
			if (res) {
				if ( typeof callback == 'function')
					callback(res);
			} else {
				app.toast("文件写入失败");
			}
		})
	}
	/**
	 *读取文件中的数据
	 * @param {Object} name 文件名
	 * @param {Object} callback 回调函数
	 */
	app.read = function(name, callback) {
		api.readFile({
			path : 'fs://' + name
		}, function(res, err) {
			if (res) {
				callback(res);
			} else {
				app.toast("文件读取失败");
			}
		})
	}
	//到底部
	app.bottom = function(callback) {
		api.addEventListener({
			name : 'scrolltobottom',
			extra : {
				threshold : 0
			}
		}, function(ret, err) {
			if ( typeof callback == 'function')
				callback(ret);
		});
		api.addEventListener({
			name : 'offline'
		}, function(ret, err) {
			api.toast({
				msg : '网络异常',
				duration : 2000,
				location : 'bottom'
			});
			api.removeEventListener({
				name : 'scrolltobottom'
			});
		});
	};
	//下拉加载
	app.refresh = function(callback) {
		api.setRefreshHeaderInfo({
			visible : true,
			loadingImg : 'widget://css/imgs/refresh.png',
			bgColor : '#f0f0f0',
			textColor : '#666',
			textDown : '下拉刷新...',
			textUp : '松开刷新...',
			showTime : true
		}, function(ret, err) {
			api.refreshHeaderLoadDone();
			//从服务器加载数据，完成后调用api.refreshHeaderLoadDone()方法恢复组件到默认状态
			if ( typeof callback == 'function')
				callback();
		});
	};
	//添加监听事件
	app.listen = function(name, callback) {
		api.addEventListener({
			name : name,
		}, function(ret, err) {
			if ( typeof callback == 'function')
				callback(ret);
		});
	};
	//发送事件
	app.sendEvent = function(name, extra) {
		var data = extra || {};
		api.sendEvent({
			name : name,
			extra : data
		});
	}
	app.remove = function(name) {
		api.removeEventListener({
			name : name
		});
	}
	app.alert = function(msg) {
		api.alert({
			msg : msg
		}, function(ret, err) {
			//coding...
		});
	}
	app.loading = function(name) {
		//监听页面加载
		app.listen(name, function() {
			api.showProgress({
				style : 'default',
				animationType : 'fade',
				title : '努力加载中...',
				text : '正在加载中...',
				modal : false
			});
		})
	}
	app.confirm = function(msg, callback) {
		api.confirm({
			title : '提示',
			msg : msg,
			buttons : ['确定', '取消']
		}, function(ret, err) {
			if (ret.buttonIndex == 1) {
				if ( typeof callback == 'function')
					callback();
				//回调操作
			}
		});
	}
	window.app = app;
})(window); 